.. _chapter_cli_reference:

=============
CLI Reference
=============

This chapter contains the auto-generated documentation of the command line interface for padrick. The information you find here is identical to the info found in the CLI command help pages.

.. click:: padrick.CLIEntryPoint:cli
   :prog: padrick
   :nested: full

   
